use axum::{
    http::{HeaderName, HeaderValue},
    Router,
};
use tower_http::{set_header::SetResponseHeaderLayer, trace::TraceLayer};

#[derive(Clone)]
pub struct Context {
    pub pool: crate::db::DbPool,
}

pub fn app() -> Router<Context> {
    Router::new()
        .layer(TraceLayer::new_for_http())
        // https://gpoddernet.readthedocs.io/en/latest/api/reference/general.html#cors
        // All endpoints should send this CORS header value so the endpoints can be used from web
        // applications
        .layer(SetResponseHeaderLayer::overriding(
            HeaderName::from_static("access-control-allow-origin"),
            HeaderValue::from_static("*"),
        ))
}
